@@ -72,6 +72,7 @@ set_reply (DBusPendingCall * pending, void *user_data)
   SpiReentrantCallClosure* closure = (SpiReentrantCallClosure *) user_data; 
 
   closure->reply = dbus_pending_call_steal_reply (pending);
+  dbus_pending_call_unref (pending);
   switch_main_context (NULL);
   g_main_loop_quit (closure->loop);
 }
@@ -88,7 +89,7 @@ send_and_allow_reentry (DBusConnection * bus, DBusMessage * message)
   closure.loop = g_main_loop_new (main_context, FALSE);
   switch_main_context (main_context);
 
-  if (!dbus_connection_send_with_reply (bus, message, &pending, -1))
+  if (!dbus_connection_send_with_reply (bus, message, &pending, -1) || !pending)
     {
       switch_main_context (NULL);
       return NULL;
